all_asset_paths

Function all_asset_paths 

pub fn all_asset_paths(
    assets: Vc<OutputAssets>,
    node_root: FileSystemPath,
    should_content_hash: Option<HashAlgorithm>,
) -> Vc<AssetPaths>
Return a list of all asset paths with filename and hash for all output assets references from the assets list. Only paths inside node_root are included.