Endpoint

Trait Endpoint 

pub trait Endpoint:
    Send
    + Sync
    + NonLocalValue
    + ValueDebug {
    // Required methods
    fn output(self: Vc<Self>) -> Vc<EndpointOutput>
       where Self: Sized;
    fn server_changed(self: Vc<Self>) -> Vc<Completion>
       where Self: Sized;
    fn client_changed(self: Vc<Self>) -> Vc<Completion>
       where Self: Sized;
    fn entries(self: Vc<Self>) -> Vc<GraphEntries>
       where Self: Sized;
    fn module_graphs(self: Vc<Self>) -> Vc<ModuleGraphs>
       where Self: Sized;
    fn project(self: Vc<Self>) -> Vc<Project>
       where Self: Sized;
    fn traced_files(self: Vc<Self>) -> Vc<FileSystemPathVec>
       where Self: Sized;

    // Provided method
    fn additional_entries(
        self: Vc<Self>,
        _graph: Vc<ModuleGraph>,
    ) -> Vc<GraphEntries>
       where Self: Sized { ... }
}

Required Methods

fn output(self: Vc<Self>) -> Vc<EndpointOutput>
where Self: Sized,

fn server_changed(self: Vc<Self>) -> Vc<Completion>
where Self: Sized,

fn client_changed(self: Vc<Self>) -> Vc<Completion>
where Self: Sized,

fn entries(self: Vc<Self>) -> Vc<GraphEntries>
where Self: Sized,

The entry modules for the modules graph.

fn module_graphs(self: Vc<Self>) -> Vc<ModuleGraphs>
where Self: Sized,

fn project(self: Vc<Self>) -> Vc<Project>
where Self: Sized,

The project this endpoint belongs to.

fn traced_files(self: Vc<Self>) -> Vc<FileSystemPathVec>
where Self: Sized,

The traced files included by this endpoint. This is only used for analysis purposes. Usually, output() includes the NFT file and everything else is handled outside of Turbopack.

Provided Methods

fn additional_entries( self: Vc<Self>, _graph: Vc<ModuleGraph>, ) -> Vc<GraphEntries>
where Self: Sized,

Additional entry modules for the module graph. This may read the module graph and return additional modules.